| aout.hyper | R Documentation |
\alpha-outliers in hypergeometric data
Given the parameters of a hypergeometric distribution, aout.hyper identifies \alpha-outliers in a given data set.
aout.hyper(data, param, alpha = 0.1, hide.outliers = FALSE)
data |
a vector. The data set to be examined. |
param |
a vector. Contains the parameters of the hypergeometric distribution: |
alpha |
an atomic vector. Determines the maximum amount of probability mass the outlier region may contain. Defaults to 0.1. |
hide.outliers |
boolean. Returns the outlier-free data if set to |
Data frame of the input data and an index named is.outlier that flags the outliers with TRUE. If hide.outliers is set to TRUE, a simple vector of the outlier-free data.
A. Rehage
Hypergeometric
set.seed(1)
lotto6aus49 <- rhyper(100, 6, 43, 6)
aout.hyper(lotto6aus49, c(6, 43, 6), 0.1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.