| aout.norm | R Documentation |
\alpha-outliers in normal data
Given the parameters of a normal distribution, aout.norm identifies \alpha-outliers in a given data set.
aout.norm(data, param = c(0, 1), alpha = 0.1, hide.outliers = FALSE)
data |
a vector. The data set to be examined. |
param |
a vector. Contains the parameters of the normal distribution: |
alpha |
an atomic vector. Determines the maximum amount of probability mass the outlier region may contain. Defaults to 0.1. |
hide.outliers |
boolean. Returns the outlier-free data if set to |
Data frame of the input data and an index named is.outlier that flags the outliers with TRUE. If hide.outliers is set to TRUE, a simple vector of the outlier-free data.
A. Rehage
Gather, U.; Kuhnt, S.; Pawlitschko, J. (2003) Concepts of outlyingness for various data structures. In J. C. Misra (Ed.): Industrial Mathematics and Statistics. New Delhi: Narosa Publishing House, 545-585.
dnorm
iris.setosa <- iris[1:51, 4]
# implosion breakdown point:
aout.norm(data = iris.setosa, param = c(median(iris.setosa), mad(iris.setosa)),
alpha = 0.01)
# better:
aout.norm(data = iris.setosa, param = c(median(iris.setosa), sd(iris.setosa)),
alpha = 0.01)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.