| aout.pois | R Documentation |
\alpha-outliers in Poisson count data
Given the parameters of a Poisson distribution, aout.pois identifies \alpha-outliers in a given data set.
aout.pois(data, param, alpha = 0.1, hide.outliers = FALSE)
data |
a vector. The data set to be examined. |
param |
a vector. Contains the parameter of the Poisson distribution: |
alpha |
an atomic vector. Determines the maximum amount of probability mass the outlier region may contain. Defaults to 0.1. |
hide.outliers |
boolean. Returns the outlier-free data if set to |
Data frame of the input data and an index named is.outlier that flags the outliers with TRUE. If hide.outliers is set to TRUE, a simple vector of the outlier-free data.
A. Rehage
dpois
aout.pois(data = c(discoveries), param = median(discoveries), alpha = 0.01)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.