createDesMat: Create design matrix for log-linear models of contingency...

View source: R/createDesMat.R

createDesMatR Documentation

Create design matrix for log-linear models of contingency tables

Description

This function creates a design matrix for contingency tables and is particularly useful for log-linear Poisson models. It uses effect coding of the variables: First the rows of the contingency table from top to bottom, then the columns from left to right.

Usage

createDesMat(n, p)

Arguments

n

Number of rows of the corresponding contingency table.

p

Number of columns of the corresponding contingency table.

Value

A (n+p-1) times (n*p) design matrix.

Author(s)

A. Rehage

References

Kuhnt, S.; Rapallo, F.; Rehage, A. (2014) Outlier detection in contingency tables based on minimal patterns. Statistics and Computing 24 (3), 481-491.

Examples

createDesMat(3, 5)

alphaOutlier documentation built on April 27, 2026, 9:07 a.m.